{% extends "base.html" %}
{% block title %}Sign up{% endblock %}
{% block full_content %}

	<br/>
    <div class="container" id="main-container">
	    <div class="row">
		    <div class="well col-md-6 col-md-offset-3">
				<h2>Sign Up</h2>
				<form role="form" method="POST">
					{% csrf_token %}
					{{ form.non_field_errors }}
					<div class="form-group {% if form.username.errors %}has-error has-feedback{% endif %}">
						<label for="id_new_username">Username:</label>
						<input type="text" class="form-control" id="id_new_username" name="username" placeholder="Enter username">
						{% if form.username.errors %}
								<span class="glyphicon glyphicon-remove form-control-feedback"></span>
								<span class="help-block">{{form.username.errors}}</span>
						{% endif %}
					</div>

					<div class="form-group {% if form.email.errors %}has-error has-feedback{% endif %}">
						<label for="id_new_email">Email:</label>
						<input type="text" class="form-control" id="id_new_email" name="email" placeholder="Enter email address">
						{% if form.email.errors %}
								<span class="glyphicon glyphicon-remove form-control-feedback"></span>
								<span class="help-block">{{form.email.errors}}</span>
						{% endif %}
					</div>

					<div class="form-group {% if form.password1.errors or form.password2.errors %}has-error has-feedback{% endif %}">
				    <label for="id_new_password">Password:</label>
				    <input type="hidden" name="signup" value="1">
				    <input type="password" class="form-control" id="id_new_password1" name="password1" placeholder="Enter password">
				    {% if form.password1.errors %}
                <span class="glyphicon glyphicon-remove form-control-feedback"></span>
                <span class="help-block">{{form.password1.errors}}</span>
				    {% endif %}
				  	</br>
				    <input type="password" class="form-control" id="id_new_password2" name="password2" placeholder="Reenter password">
				    {% if form.password2.errors %}
                <span class="glyphicon glyphicon-remove form-control-feedback"></span>
                <span class="help-block">{{form.password2.errors}}</span>
				    {% endif %}
					</div>

					<button type="submit" class="btn btn-default">Submit</button>
				</form>
			</div>
		</div>
	</div>


{% endblock %}

