# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2016-11-21 17:08
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0004_subscriptionprofile'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='billsearchsubscription',
            name='search_facets',
        ),
        migrations.RemoveField(
            model_name='billsearchsubscription',
            name='search_term',
        ),
        migrations.AddField(
            model_name='billsearchsubscription',
            name='search_params',
            field=django.contrib.postgres.fields.jsonb.JSONField(db_index=True, null=True),
        ),
    ]
